/* This is "block3.c", written to accompany Introduction to
   Scientific Programming by Joseph L. Zachary .*/

/* This program calculates the position of a block on an infinite ramp
   in the presence of friction as described in Chapter 12 of the
   text. */


#include <stdio.h>
#include <math.h>



/* We obtain the angle of the ramp in degrees, the coefficient of
   friction of the block against the ramp, and the elapsed time in
   seconds since the block was released, and display the distance
   in meters of the block from its original position. */

void main (void)
{  
  double angle,    /* Angle of inclination of the ramp in degrees. */
         theta,    /* Angle of inclination of the ramp in radians. */
         time,     /* Time since block was released in seconds. */
         pos,      /* Position of block in meters. */
         mu,       /* Coefficient of friction of block against ramp. */
         factor;   /* Dimensionless factor that determines how the
                      block accelerates. */


  /* Obtain the ramp angle and convert to radians. */

  printf("Enter the angle of the ramp (degrees): ");
  scanf("%lf", &angle);
  theta = acos(-1) * angle/180;


  /* Obtain the coefficient of friction. */

  printf("Enter the coefficient of friction: ");
  scanf("%lf", &mu);


  /* Obtain the time since release. */

  printf("Enter the time (seconds): ");
  scanf("%lf", &time);


  /* Calculate the factor that governs acceleration. */

  factor = sin(theta) - mu * cos(theta);


  /* Calculate the position of block.  Prior to time zero, the block
     does not move.  If "factor" is not positive, the block does not
     move either.  Notice how we have used the or (||) operator to
     simplify the conditional from "block2.c". */

  if (time < 0 || factor < 0) {
    pos = 0;
  }
  else {
    pos = 1./2. * 9.8 * factor * time * time;
  }


  /* Report the result. */

  printf("Position of the block is %g meters\n", pos);

}
