/* This is "complex.h", written to accompany Introduction to
   Scientific Programming by Joseph L. Zachary. */

/* This file declares the interface to a complex number ADT. */



/* This structure is used as the representation of the complex
   number ADT.  The details of the representation (i.e., the
   fields of the structure) are relevant only to "complex.c",
   which implements the ADT.  All other programs should
   manipulate complex numbers only with the interface functions
   declared below. */

typedef struct {
  double real;      /* Real component of complex number */
  double imag;      /* Imaginary component of complex number */
} complex;



/* Returns the complex number whose real part is "real" and whose
   imaginary part is "imaginary". */

complex make (double real, double imaginary);


/* Reads a complex number from the keyboard and returns it.  The
   number should be entered in the form a+bi or a-bi, where a and
   b stand for arbitrary doubles. */

complex read (void);


/* Writes "c" to the display in the form a+bi or a-bi, where a and
   b stand for arbitrary doubles. */

void write (complex c);


/* Returns c1+c2. */

complex add (complex c1, complex c2);


/* Returns c1-c2. */

complex sub (complex c1, complex c2);


/* Returns c1*c2. */

complex mul (complex c1, complex c2);


/* Returns c1/c2. */

complex div (complex c1, complex c2);


/* Returns |c|. */

double absval (complex c);
